# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Contract.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='Contract.proto',
  package='communication',
  syntax='proto2',
  serialized_options=b'\n\024de.dlr.fame.protobufB\tContracts',
  serialized_pb=b'\n\x0e\x43ontract.proto\x12\rcommunication\"\xb3\x01\n\rProtoContract\x12\x10\n\x08senderId\x18\x01 \x02(\x03\x12\x12\n\nreceiverId\x18\x02 \x02(\x03\x12\x13\n\x0bproductName\x18\x03 \x02(\t\x12\x19\n\x11\x66irstDeliveryTime\x18\x04 \x02(\x03\x12\x1f\n\x17\x64\x65liveryIntervalInSteps\x18\x05 \x02(\x03\x12+\n\x0e\x65xpirationTime\x18\x06 \x01(\x03:\x13\x39\x32\x32\x33\x33\x37\x32\x30\x33\x36\x38\x35\x34\x37\x37\x35\x38\x30\x37\x42!\n\x14\x64\x65.dlr.fame.protobufB\tContracts'
)




_PROTOCONTRACT = _descriptor.Descriptor(
  name='ProtoContract',
  full_name='communication.ProtoContract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='senderId', full_name='communication.ProtoContract.senderId', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receiverId', full_name='communication.ProtoContract.receiverId', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='productName', full_name='communication.ProtoContract.productName', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='firstDeliveryTime', full_name='communication.ProtoContract.firstDeliveryTime', index=3,
      number=4, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deliveryIntervalInSteps', full_name='communication.ProtoContract.deliveryIntervalInSteps', index=4,
      number=5, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expirationTime', full_name='communication.ProtoContract.expirationTime', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=True, default_value=9223372036854775807,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=213,
)

DESCRIPTOR.message_types_by_name['ProtoContract'] = _PROTOCONTRACT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoContract = _reflection.GeneratedProtocolMessageType('ProtoContract', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCONTRACT,
  '__module__' : 'Contract_pb2'
  # @@protoc_insertion_point(class_scope:communication.ProtoContract)
  })
_sym_db.RegisterMessage(ProtoContract)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
