# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: InputFile.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from famepy.protobuf_definitions import Contract_pb2 as Contract__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='InputFile.proto',
  package='iobinary',
  syntax='proto2',
  serialized_options=b'\n\024de.dlr.fame.protobufB\005Input',
  serialized_pb=b'\n\x0fInputFile.proto\x12\x08iobinary\x1a\x0e\x43ontract.proto\"\xc0\x06\n\tInputData\x12\r\n\x05runId\x18\x01 \x02(\x03\x12*\n\x06\x63onfig\x18\x02 \x02(\x0b\x32\x1a.iobinary.InputData.Config\x12>\n\x10outputParameters\x18\x03 \x01(\x0b\x32$.iobinary.InputData.OutputParameters\x12\x35\n\ntimeSeries\x18\x04 \x03(\x0b\x32!.iobinary.InputData.TimeSeriesDao\x12+\n\x05\x61gent\x18\x05 \x03(\x0b\x32\x1c.iobinary.InputData.AgentDao\x12.\n\x08\x63ontract\x18\x06 \x03(\x0b\x32\x1c.communication.ProtoContract\x1a\x41\n\x06\x43onfig\x12\x11\n\tstartTime\x18\x01 \x02(\x03\x12\x10\n\x08stopTime\x18\x02 \x02(\x03\x12\x12\n\nrandomSeed\x18\x03 \x02(\x03\x1aZ\n\x10OutputParameters\x12\x16\n\x0eoutputInterval\x18\x01 \x02(\x05\x12\x15\n\routputProcess\x18\x02 \x02(\x05\x12\x17\n\x0f\x61\x63tiveClassName\x18\x03 \x03(\t\x1a\x91\x01\n\rTimeSeriesDao\x12\x10\n\x08seriesId\x18\x01 \x02(\x05\x12\x12\n\nseriesName\x18\x02 \x01(\t\x12\x32\n\x03row\x18\x03 \x03(\x0b\x32%.iobinary.InputData.TimeSeriesDao.Row\x1a&\n\x03Row\x12\x10\n\x08timeStep\x18\x01 \x02(\x03\x12\r\n\x05value\x18\x02 \x02(\x01\x1a\xf0\x01\n\x08\x41gentDao\x12\n\n\x02id\x18\x01 \x02(\x03\x12\x11\n\tclassName\x18\x02 \x02(\t\x12\x31\n\x05\x66ield\x18\x03 \x03(\x0b\x32\".iobinary.InputData.AgentDao.Field\x1a\x91\x01\n\x05\x46ield\x12\x11\n\tfieldName\x18\x01 \x02(\t\x12\x1d\n\x08seriesId\x18\x02 \x01(\x05:\x0b-2147483648\x12\x1d\n\x08intValue\x18\x03 \x01(\x05:\x0b-2147483648\x12\"\n\x0bstringValue\x18\x04 \x01(\t:\rENTRY_MISSING\x12\x13\n\x0b\x64oubleValue\x18\x05 \x03(\x01\x42\x1d\n\x14\x64\x65.dlr.fame.protobufB\x05Input'
  ,
  dependencies=[Contract__pb2.DESCRIPTOR,])




_INPUTDATA_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='iobinary.InputData.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='startTime', full_name='iobinary.InputData.Config.startTime', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stopTime', full_name='iobinary.InputData.Config.stopTime', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='randomSeed', full_name='iobinary.InputData.Config.randomSeed', index=2,
      number=3, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=395,
)

_INPUTDATA_OUTPUTPARAMETERS = _descriptor.Descriptor(
  name='OutputParameters',
  full_name='iobinary.InputData.OutputParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='outputInterval', full_name='iobinary.InputData.OutputParameters.outputInterval', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputProcess', full_name='iobinary.InputData.OutputParameters.outputProcess', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activeClassName', full_name='iobinary.InputData.OutputParameters.activeClassName', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=487,
)

_INPUTDATA_TIMESERIESDAO_ROW = _descriptor.Descriptor(
  name='Row',
  full_name='iobinary.InputData.TimeSeriesDao.Row',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeStep', full_name='iobinary.InputData.TimeSeriesDao.Row.timeStep', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='iobinary.InputData.TimeSeriesDao.Row.value', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=597,
  serialized_end=635,
)

_INPUTDATA_TIMESERIESDAO = _descriptor.Descriptor(
  name='TimeSeriesDao',
  full_name='iobinary.InputData.TimeSeriesDao',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seriesId', full_name='iobinary.InputData.TimeSeriesDao.seriesId', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seriesName', full_name='iobinary.InputData.TimeSeriesDao.seriesName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row', full_name='iobinary.InputData.TimeSeriesDao.row', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INPUTDATA_TIMESERIESDAO_ROW, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=490,
  serialized_end=635,
)

_INPUTDATA_AGENTDAO_FIELD = _descriptor.Descriptor(
  name='Field',
  full_name='iobinary.InputData.AgentDao.Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fieldName', full_name='iobinary.InputData.AgentDao.Field.fieldName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seriesId', full_name='iobinary.InputData.AgentDao.Field.seriesId', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-2147483648,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intValue', full_name='iobinary.InputData.AgentDao.Field.intValue', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-2147483648,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stringValue', full_name='iobinary.InputData.AgentDao.Field.stringValue', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"ENTRY_MISSING".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doubleValue', full_name='iobinary.InputData.AgentDao.Field.doubleValue', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=733,
  serialized_end=878,
)

_INPUTDATA_AGENTDAO = _descriptor.Descriptor(
  name='AgentDao',
  full_name='iobinary.InputData.AgentDao',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='iobinary.InputData.AgentDao.id', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='className', full_name='iobinary.InputData.AgentDao.className', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field', full_name='iobinary.InputData.AgentDao.field', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INPUTDATA_AGENTDAO_FIELD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=638,
  serialized_end=878,
)

_INPUTDATA = _descriptor.Descriptor(
  name='InputData',
  full_name='iobinary.InputData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='runId', full_name='iobinary.InputData.runId', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='iobinary.InputData.config', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputParameters', full_name='iobinary.InputData.outputParameters', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeSeries', full_name='iobinary.InputData.timeSeries', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agent', full_name='iobinary.InputData.agent', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contract', full_name='iobinary.InputData.contract', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INPUTDATA_CONFIG, _INPUTDATA_OUTPUTPARAMETERS, _INPUTDATA_TIMESERIESDAO, _INPUTDATA_AGENTDAO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=878,
)

_INPUTDATA_CONFIG.containing_type = _INPUTDATA
_INPUTDATA_OUTPUTPARAMETERS.containing_type = _INPUTDATA
_INPUTDATA_TIMESERIESDAO_ROW.containing_type = _INPUTDATA_TIMESERIESDAO
_INPUTDATA_TIMESERIESDAO.fields_by_name['row'].message_type = _INPUTDATA_TIMESERIESDAO_ROW
_INPUTDATA_TIMESERIESDAO.containing_type = _INPUTDATA
_INPUTDATA_AGENTDAO_FIELD.containing_type = _INPUTDATA_AGENTDAO
_INPUTDATA_AGENTDAO.fields_by_name['field'].message_type = _INPUTDATA_AGENTDAO_FIELD
_INPUTDATA_AGENTDAO.containing_type = _INPUTDATA
_INPUTDATA.fields_by_name['config'].message_type = _INPUTDATA_CONFIG
_INPUTDATA.fields_by_name['outputParameters'].message_type = _INPUTDATA_OUTPUTPARAMETERS
_INPUTDATA.fields_by_name['timeSeries'].message_type = _INPUTDATA_TIMESERIESDAO
_INPUTDATA.fields_by_name['agent'].message_type = _INPUTDATA_AGENTDAO
_INPUTDATA.fields_by_name['contract'].message_type = Contract__pb2._PROTOCONTRACT
DESCRIPTOR.message_types_by_name['InputData'] = _INPUTDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InputData = _reflection.GeneratedProtocolMessageType('InputData', (_message.Message,), {

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _INPUTDATA_CONFIG,
    '__module__' : 'InputFile_pb2'
    # @@protoc_insertion_point(class_scope:iobinary.InputData.Config)
    })
  ,

  'OutputParameters' : _reflection.GeneratedProtocolMessageType('OutputParameters', (_message.Message,), {
    'DESCRIPTOR' : _INPUTDATA_OUTPUTPARAMETERS,
    '__module__' : 'InputFile_pb2'
    # @@protoc_insertion_point(class_scope:iobinary.InputData.OutputParameters)
    })
  ,

  'TimeSeriesDao' : _reflection.GeneratedProtocolMessageType('TimeSeriesDao', (_message.Message,), {

    'Row' : _reflection.GeneratedProtocolMessageType('Row', (_message.Message,), {
      'DESCRIPTOR' : _INPUTDATA_TIMESERIESDAO_ROW,
      '__module__' : 'InputFile_pb2'
      # @@protoc_insertion_point(class_scope:iobinary.InputData.TimeSeriesDao.Row)
      })
    ,
    'DESCRIPTOR' : _INPUTDATA_TIMESERIESDAO,
    '__module__' : 'InputFile_pb2'
    # @@protoc_insertion_point(class_scope:iobinary.InputData.TimeSeriesDao)
    })
  ,

  'AgentDao' : _reflection.GeneratedProtocolMessageType('AgentDao', (_message.Message,), {

    'Field' : _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
      'DESCRIPTOR' : _INPUTDATA_AGENTDAO_FIELD,
      '__module__' : 'InputFile_pb2'
      # @@protoc_insertion_point(class_scope:iobinary.InputData.AgentDao.Field)
      })
    ,
    'DESCRIPTOR' : _INPUTDATA_AGENTDAO,
    '__module__' : 'InputFile_pb2'
    # @@protoc_insertion_point(class_scope:iobinary.InputData.AgentDao)
    })
  ,
  'DESCRIPTOR' : _INPUTDATA,
  '__module__' : 'InputFile_pb2'
  # @@protoc_insertion_point(class_scope:iobinary.InputData)
  })
_sym_db.RegisterMessage(InputData)
_sym_db.RegisterMessage(InputData.Config)
_sym_db.RegisterMessage(InputData.OutputParameters)
_sym_db.RegisterMessage(InputData.TimeSeriesDao)
_sym_db.RegisterMessage(InputData.TimeSeriesDao.Row)
_sym_db.RegisterMessage(InputData.AgentDao)
_sym_db.RegisterMessage(InputData.AgentDao.Field)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
